/* Banqix TV & Internet Business HTML-5 Template */

/* RTL Style CSS Code */

.rtl .row,
.rtl .d-flex{
	flex-direction: row-reverse;
}

.rtl .main-menu .navigation > li{
	float:right;
}

.rtl .sticky-header .logo{
	float:right;
	padding-left:25px;
}

.rtl .main-menu{
	
	text-align:right;
}

.rtl .main-header .main-menu .navigation > li > ul > li > ul > li,
.rtl .main-header .main-menu .navigation > li > ul > li,
.rtl .main-menu .navigation > li > ul > li{
	text-align:right;
}

.rtl .main-header .main-menu .navigation > li > ul{
	padding:20px 25px 20px 25px;
}

.rtl .main-header .main-menu .navigation > li > ul > li > a:before{
	right:0px;
	left:auto;
	opacity: 0;
}

.rtl .main-menu .navigation > li > ul > li:hover > a{
	padding-left:0px !important;
	padding-right:30px;
}

.rtl .main-menu .navigation > li > ul > li > a:before{
	left:auto;
	right:8px;
}

.rtl .main-menu .navigation > li > ul > li.dropdown > a:after{
	right:auto;
	left:10px;
	transform:rotate(180deg);
}

.rtl .main-menu .navigation > li > ul > li > ul{
	left:auto;
	right:100%;
}

.rtl .main-menu .navigation li > ul > li.dropdown:hover > ul{
	
}

.rtl .main-header .main-menu .navigation > li > ul > li > ul{
	right:100%;
	left:auto;
}

.rtl .main-menu .navigation > li > ul{
	left:auto;
	right:0px;
}

.rtl .main-menu .navigation > li.dropdown:hover > ul{
	left:auto;
	right:0px;
}

.rtl .main-menu .navigation > li > ul > li > ul > li:hover > a{
	padding-left:0px;
	padding-right:30px;
}

.rtl .main-menu .navigation > li > ul > li > ul > li > a:before{
	left:auto;
	right:8px;
	opacity: 0;
}

.rtl .main-header .main-menu .navigation > li:first-child{
	margin-right: 0px;
}

.rtl .main-header .main-menu .navigation > li:last-child{
	margin-right: 25px;
}

.rtl .header-phone_box{
	margin-left:0px;
	margin-right: 32px;
}

.rtl .main-header .outer-box{
	margin-left: 0px;
	margin-right: 0px;
}

.rtl .search-popup .form-group input[type="text"],
.rtl .search-popup .form-group input[type="search"]{
	text-align: right;
}

.rtl .search-popup .form-group input[type="submit"],
.rtl .search-popup .form-group button{
	text-align: right;
}

.rtl .search-popup .form-group input[type="submit"],
.rtl .search-popup .form-group button{
	right: 0px;
	left: auto;
}

.rtl .main-header .header-lower .logo-box .logo{
	padding: 25px 0px 20px;
}

.rtl .header-top_list li{
	margin-right: 0px;
	margin-left: 20px;
	flex-direction: row-reverse;
}

.rtl .header-phone_box{
	text-align: right;
	flex-direction: row-reverse;
}

.rtl .price-one_content-outer,
.rtl .about-one_image-content,
.rtl .service-block_one-inner,
.rtl .language-dropdown .dropdown-menu .dropdown-item,
.rtl .login-dropdown .dropdown-menu .dropdown-item{
	text-align: right;
}

.rtl .login-dropdown{
	margin-left: 0px;
	margin-right: 10px;
}

.rtl .slider-one_content{
    display: flex;
    justify-content: end;
    text-align: right;
}

.rtl .service-block_one-inner:before{
	left: 20px;
	right: auto;
}

.rtl .service-block_one-inner:after{
	left: 80px;
	right: -20px;
}

.rtl .about-one_content-outer{
	text-align: right;
	padding-left: 0px;
	padding-right: 20px;
}

.rtl .header-style-one.fixed-header .header-lower .outer-box{
	margin-top: 0px;
}

.rtl .about-block_one-icon{
	right: 0px;
	left: auto;
}

.rtl .about-block_one-content{
	margin-left: 0px;
	margin-right: 20px;
}

.rtl .price-block_one-list li{
	text-align: right;
}

.rtl .price-block_one-list li i{
	left: 0px;
	right: auto;
}

.rtl .counter-one_connt-outer{
	margin-right: 0px;
	margin-left: -55px;
}

.rtl .counter-one_play{
	margin-left: 0px;
	margin-right: 170px;
}

.rtl .counter-one_image-layer{
	right: 100px;
	left: -220px;
}

.rtl .counter-one_circle-layer{
	right: 70px;
}

.rtl .subscribe-one_mobile{
	right: -80px;
	left: auto;
}

.rtl .subscribe-one_content-outer{
	text-align: right;
}

.rtl .main-footer,
.rtl .news-block_one-content,
.rtl .watch-one_socials,
.rtl .watch-one_info-list,
.rtl .testimonial-block_one-author_box span,
.rtl .testimonial-block_one-text,
.rtl .default-form .form-group input[type="text"],
.rtl .default-form .form-group input[type="password"],
.rtl .default-form .form-group input[type="tel"],
.rtl .default-form .form-group input[type="email"],
.rtl .default-form .form-group textarea,
.rtl .default-form .form-group select{
	text-align: right;
}

.rtl .watch-one_info-outer{
	margin-right: 0px;
}

.rtl .watch-one_form-outer{
	padding-right: 30px;
	padding-left: 50px;
}

.rtl .default-form .form-group .icon{
	left: 30px;
	right: auto;
}

.rtl .news-block_one-more span{
	left: 25px;
	right: auto;
}

.rtl .news-block_one-meta{
	justify-content: end;
}

.rtl .news-block_one-meta li{
	flex-direction: row-reverse;
}

.rtl .timing-list li span{
	left: 0px;
	right: auto;
}

.rtl .footer-text{
	max-width: 100%;
}

.rtl .app-buttons{
	margin-left: -45px;
	margin-right: 0px;
}

.rtl .header-two_socials{
	border: none;
	padding-left: 0px;
}

.rtl .header-search_box .form-group input[type="text"],
.rtl .header-search_box .form-group input[type="search"]{
	text-align: right;
	padding-right: 20px;
}

.rtl .header-search_box .form-group button{
	left: 5px;
	right: auto;
}

.rtl .slider-two_content{
	text-align: right;
	flex-direction: inherit;
}

.rtl .slider-two_price{
	margin-left: 25px;
}

.rtl .slider-two_video .play-box .fa{
	float: right;
}

.rtl .cta-one,
.rtl .team-block_two-content,
.rtl .area-one .left-box,
.rtl .about-two_content-outer,
.rtl .service-block_two-inner,
.rtl .gallery-block_two-content,
.rtl .area-form .form-group input[type="text"],
.rtl .area-form .form-group input[type="password"],
.rtl .area-form .form-group input[type="tel"],
.rtl .area-form .form-group input[type="email"],
.rtl .area-form .form-group textarea,
.rtl .area-form .form-group select{
	text-align: right;
}

.rtl .service-block_two-number{
	right: auto;
	left: -20px;
}

.rtl .service-block_two-heading::before{
	right: 0px;
	left: auto;
}

.rtl .about-two_image-two{
	left: 10px;
}

.rtl .about-two_image-outer{
	padding-right: 0px;
	padding-left: 50px;
	text-align: right;
}

.rtl .about-two_payment-inner{
	text-align: right;
	padding-left: 0px;
	padding-right: 80px;
}

.rtl .about-two_payment-icon{
	right: 0px;
	left: auto;
}

.rtl .about-two_list li{
	flex-direction: row-reverse;
}

.rtl .services-three .service-three_buttons{
	margin-left: 0px;
	margin-right: -55px;
}

.rtl .service-three_btn{
	text-align: right;
	padding: 35px 180px 30px 30px;
}

.rtl .service-three_btn .icon{
	right: 30px;
	left: auto;
}

.rtl .gallery-block_two-meta{
	flex-direction: row-reverse;
}

.rtl .testimonial-block_two-content{
	text-align: right;
	padding-right: 65px;
}

.rtl .faq-one_image-layer{
	opacity: 0;
}

.rtl .faq-one_accordian-outer{
	margin-left: 0px;
	margin-right: 50px;
}

.rtl .faq-one_image-outer{
	margin-left: 0px;
}

.rtl .faq-one_vector{
	background-size: contain;
}

.rtl .news-block_two-content{
	text-align: right;
}

.rtl .news-block_two-meta{
	justify-content: end;
}

.rtl .service-block_three-list li,
.rtl .news-block_two-meta li{
	flex-direction: row-reverse;
}

.rtl .main-header.header-style-three .header-upper .logo-box .logo::before{
	width: 100%;
}

.rtl .main-header.header-style-three .header-upper .logo-box .logo{
	padding: 24px 40px;
}

.rtl .header-info_box-inner{
	text-align: right;
	padding-left: 0px;
	padding-right: 60px;
}

.rtl .header-info_box-icon{
	right: 0px;
	left: auto;
}

.rtl .main-header.header-style-three .header-upper .inner-container{
	padding-right: 0px;
	padding-left: 30px;
}

.rtl .slider-three_image-two{
	left: 0px;
	border-radius: 0px 0px;
}

.rtl .slider-three_image img{
	margin-left: 0px;
}

.rtl .navSidebar-button{
	margin-left: 0px;
	margin-right: 15px;
}

.rtl .main-header .options-box{
	margin-left: 0px;
	margin-right: 60px;
}

.rtl .sidebar-info-contents .lower-box{
	text-align: right;
}

.rtl .post-block .inner-box{
	padding-left: 0px;
	padding-right: 120px;
}

.rtl .post-block .inner-box .image{
	right: 0px;
	left: auto;
}

.rtl .slider-three_content-inner{
	text-align: right;
	padding-right: 30px;
}

.rtl .team-block_three-content,
.rtl .internet-one_clock,
.rtl .internet-one_content .lower-box h6,
.rtl .service-block_three-content{
	text-align: right;
}

.rtl .about-three_content-outer{
	text-align: right;
}

.rtl .about-three_block-inner{
	padding-left: 0px;
	padding-right: 100px;
}

.rtl .about-three_block-icon{
	right: 0px;
	left: auto;
}

.rtl .about-three_map{
	margin-left: -100px;
}

.rtl .about-three_map img{
	max-width: 100%;
}

.rtl .services-five_title-bg{
	left: -10px;
	right: auto;
	border-radius: 25px;
}

.rtl .services-five_blocks-outer .services-five_carousel{
	margin-left: -330px;
	margin-right: 0px;
}

.rtl .services-five_title-outer{
	text-align: right;
	padding-left: 30px;
	padding-right: 0px;
}

.rtl .news-block_three-content,
.rtl .testimonial-block_three-text,
.rtl .fluid-one .right-box_inner{
	text-align: right;
}

.rtl .feature-block_one-inner{
	max-width: 100%;
	padding-left: 0px;
	padding-right: 140px;
}

.rtl .feature-block_one-image{
	left: auto;
	right: 0px;
}

.rtl .fluid-one_price{
	margin-left: 0px;
	margin-right: 30px;
}

.rtl .internet-one_image{
	margin-left: 0px;
	margin-right: 50px;
}

.rtl .internet-one_content{
	padding-left: 0px;
	padding-right: 70px;
}

.rtl .internet-one_list{
	justify-content: end;
}

.rtl .internet-one_list li{
	flex-direction: row-reverse;
}

.rtl .internet-one_content .lower-box::before{
	left: 50%;
}

.rtl .movie-block_one-inner:before{
	right: auto;
	left: -20px;
}

.rtl .gallery-block_three-pattern{
	opacity: 0;
	visibility: hidden;
}

.rtl .gallery-block_three-content{
	padding: 25px 20px;
	text-align: right;
	border-radius: 0px 15px 0px 0px;
	background-color: var(--white-color);
}

.rtl .gallery-block_three-arrow{
	left: 10px;
	top: 10px;
	right: auto;
	bottom: auto;
}

.rtl .gallery-block_three-rating{
	justify-content: end;
}

.rtl .testimonial-block_three-color::before{
	right: 20px;
	left: auto;
}

.rtl .news-block_four-content{
	right: 30px;
	text-align: right;
}

.rtl .testimonial-block_three-author{
	left: 20px;
	right: auto;
}

.rtl .testimonial-block_three-author_box{
	padding-right: 20px;
}

.rtl .news-block_four-meta{
	justify-content: end;
}

.rtl .news-block_four-date{
	left: 5px;
	right: auto;
}

.rtl .news-three .sec-title .left-box{
	text-align: right;
}

.rtl .main-header.header-style-three .header-lower .d-flex{
	justify-content: center !important;
}

.rtl .header-style-three.fixed-header .header-lower .logo{
	position: relative;
	margin-left: 30px;
}

.rtl .news-block_three-meta{
	justify-content: end;
}

.rtl .news-block_three-meta li{
	flex-direction: row-reverse;
}

.rtl .news-block_three-date{
	left: 0px;
	right: auto;
}

.rtl .footer-two_subscribe-column .inner-column{
	text-align: right;
}

.rtl .subscribe-box .form-group input[type="text"],
.rtl .subscribe-box .form-group input[type="email"]{
	text-align: right;
	padding-right: 30px;
}

.rtl .subscribe-box .form-group button{
	left: 5px;
	right: auto;
}

.rtl .footer-style_two .logo{
	margin-right: 0px;
}

.rtl .about-sidebar .content-box,
.rtl .footer-style_two{
	text-align: right;
}

.rtl .header-top_list-two li{
	flex-direction: row-reverse;
}

.rtl .about-one_list li{
	text-align: right;
	padding-left: 0px;
	padding-right: 30px;
}

.rtl .about-one_list li:before{
	left: auto;
	right: 0px;
}

.rtl .about-sidebar .social-box{
	text-align: right;
	margin-left: 0px;
	margin-right: 35px;
}

.rtl .about-widget{
	margin-left: 0px;
	margin-right: 15px;
}

.rtl .slider-four_image img{
	max-width: 100%;
	clip-path: inherit;
}

.rtl .slider-four_image{
	margin-left: -340px;
	margin-right: 60px;
}

.rtl .service-block_five-text,
.rtl .slider-four_content-inner{
	text-align: right;
}

.rtl .slider-four_title::before{
	left: auto;
	right: 0px;
}

.rtl .slider-four_heading{
	margin-right: 0px;
	margin-left: -70px;
}

.rtl .service-block_five-title{
	text-align: right;
	padding-left: 80px;
	padding-right: 50px;
}

.rtl .about-four_content-outer{
	margin-left: 0px;
	text-align: right;
}

.rtl .about-four_list li{
	flex-direction: row-reverse;
}

.rtl .facility-one_image-two::before{
	position: absolute;
	content: '';
	left: 0px;
	top: 0px;
	right: 0px;
	bottom: 0px;
	opacity: 0.80;
	background-color: var(--color-two);
}

.rtl .facility-one_content-outer{
	text-align: right;
}

.rtl .facility-one .sec-title .sec-title_heading{
	padding-right: 0px;
}

.rtl .facility-one_block-outer{
	margin-left: 0px;
}

.rtl .testimonial-block_four-content,
.rtl .time-one_title-outer,
.rtl .price-block_two-list li{
	text-align: right;
}

.rtl .price-block_two-list li i{
	left: 0px;
	right: auto;
}

.rtl .counter-block_three-inner{
	text-align: right;
	padding-left: 0px;
	padding-right: 140px;
}

.rtl .counter-block_three-icon{
	right: 0px;
	left: auto;
}

.rtl .team-block_four-content{
	text-align: right;
	padding-right: 60px;
}

.rtl .gallery-four_image{
	left: -50px;
	right: auto;
	border-radius: 0px 100px 0px 0px;
}

.rtl .news-block_five-content,
.rtl .gallery-four .left-box{
	text-align: right;
}

.rtl .news-block_five-meta{
	justify-content: end;
}

.rtl .news-block_five-meta li,
.rtl .news-block_five-author{
	flex-direction: row-reverse;
}

.rtl .page-title_side-image{
	left: -120px;
	right: auto;
}

.rtl .page-title_side-image img{
	max-width: 100%;
	clip-path: inherit;
}

.rtl .service-detail,
.rtl .page-title_two,
.rtl .team-detail_content-outer,
.rtl .privacy-section,
.rtl .accordion-box,
.rtl .page-title{
	text-align: right;
}

.rtl .privacy-section .privacy-list li{
	padding-left: 0px;
	padding-right: 25px;
}

.rtl .privacy-section .privacy-list li:before{
	right: 0px;
	left: auto;
}

.rtl .page-title h2{
	z-index: 1;
}

.rtl .blog-detail_meta li,
.rtl .shop-detail_check-list li,
.rtl .service-detail_list-two li,
.rtl .team-detail_list li{
	flex-direction: row-reverse;
}

.rtl .default-skill-title{
	text-align: left;
}

.rtl .blog-detail_meta,
.rtl .page-title_two .breadcrumb{
	justify-content: end;
}

.rtl .page-title_two-breadcrumb-icon{
	right: 0px;
	left: auto;
}

.rtl .sidebar .search-box .form-group input[type="text"],
.rtl .sidebar .search-box .form-group input[type="search"]{
	text-align: right;
	padding-right: 20px;
}

.rtl .sidebar .search-box .form-group button{
	left: 5px;
	right: auto;
}

.rtl .category-list li a{
	text-align: right;
}

.rtl .category-list li a::before{
	left: 20px;
	right: auto;
}

.rtl .service-detail_list li{
	padding-left: 0px;
	padding-right:25px;
}

.rtl .service-detail_list li:before{
	right: 0px;
	left: auto;
}

.rtl .product-post{
	text-align: right;
	padding-left: 0px;
	padding-right: 90px;
}

.rtl .product-post_image{
	right: 0px;
	left: auto;
}

.rtl .shop-detail_content-column .inner-column{
	text-align: right;
	padding-left: 0px;
	padding-right: 30px;
}

.rtl .quantity-box strong{
	margin-right: 0px;
	margin-left: 15px;
}

.rtl .blog-detail_content,
.rtl .contact-form .form-group input[type="text"],
.rtl .contact-form .form-group input[type="password"],
.rtl .contact-form .form-group input[type="tel"],
.rtl .contact-form .form-group input[type="email"],
.rtl .contact-form .form-group textarea,
.rtl .shop-comment-form .form-group input[type="text"],
.rtl .shop-comment-form .form-group input[type="password"],
.rtl .shop-comment-form .form-group input[type="tel"],
.rtl .shop-comment-form .form-group input[type="email"],
.rtl .shop-comment-form .form-group textarea,
.rtl .shop-detail .lower-box{
	text-align: right;
}

.rtl .review-author_box{
	text-align: right;
	padding-left: 0px;
	padding-right: 210px;
}

.rtl .review-author_box .author-image{
	right: 0px;
	left: auto;
}

.rtl .review-author_box .rating{
	left: 0px;
	right: auto;
}

.rtl .coming-soon .emailed-form .form-group input[type="text"],
.rtl .coming-soon .emailed-form .form-group input[type="tel"],
.rtl .coming-soon .emailed-form .form-group input[type="email"],
.rtl .coming-soon .emailed-form .form-group textarea{
	text-align: right;
	padding-right: 25px;
}

.rtl .coming-soon .emailed-form .form-group input[type="submit"],
.rtl .coming-soon .emailed-form button{
	right: auto;
	left: 0px;
}

.rtl .service-three_btn-line{
	display: none;
}

.rtl .blog-detail_list li{
	padding-left: 0px;
	padding-right: 20px;
}

.rtl .blog-detail_list li::before{
	right: 0px;
	left: auto;
}

.rtl .contact-one_list li{
	text-align: right;
	padding-left: 0px;
	padding-right: 60px;
}

.rtl .contact-one_list li i{
	right: 0px;
	left: auto;
}

.rtl .search-popup .close-search{
	left: 25px;
	right: auto;
}

.rtl .mobile-menu .close-btn{
	right: auto;
	left: 15px;
}

.rtl .mobile-menu .nav-logo,
.rtl .mobile-menu .menu-box{
	text-align: right;
}

.rtl .main-header .mobile-menu .navigation li.dropdown .dropdown-btn{
	right: auto;
	left: 0px;
}

.rtl .main-header .mobile-menu .navigation li.dropdown .dropdown-btn::after{
	right: 0px;
	left: auto;
}

/* Want Sticky Header */

.want-sticky-header .main-header{
	display:none;
}

/* RTL Responsive */

@media only screen and (max-width: 2000px){

}

@media only screen and (max-width: 1750px){

}

@media only screen and (max-width: 1600px){

}

@media only screen and (max-width: 1650px){

}

@media only screen and (max-width: 1550px){

	.rtl .counter-one_play{
		margin-right: 40px;
	}

}

@media only screen and (max-width: 1500px){

}

@media only screen and (max-width: 1400px){

}

@media only screen and (max-width: 1300px){

}

@media only screen and (max-width: 1240px){

	.rtl .counter-one-image{
		margin-left: 0px;
		margin-right: 80px;
	}

	.rtl .counter-one_play{
		margin-right: 0px;
	}

	.rtl .header-style-three .header-lower .logo{
		margin-left: 25px;
	}

	.rtl .internet-one_content{
		padding-right: 10px;
	}

	.rtl .slider-three_content-inner{
		padding-right: 0px;
		padding-bottom: 100px;
	}

	.rtl .slider-three_image img{
		max-width: 100%;
	}

}

@media only screen and (max-width: 1140px){

	.rtl .about-block_one-content{
		padding-right: 50px;
	}

	.rtl .about-one_content-outer{
		padding-right: 0px;
	}

	.rtl .price-one_pricing-outer{
		padding-left: 0px;
	}

	.rtl .about-block_one-content{
		padding-left: 20px;
	}

	.rtl .services-three .service-three_buttons{
		margin-right: 0px;
	}

	.rtl .about-two_image-outer{
		padding-left: 0px;
	}

}

@media only screen and (max-width: 1023px){

	.rtl .main-header .mobile-nav-toggler{
		margin-left: 0px;
		margin-right: 20px;
	}

	.rtl .main-header .header-lower .logo-box .logo {
		padding: 10px 0px 10px;
	}

}

@media only screen and (max-width: 991px){

	.main-header.header-style-one .header-lower .outer-box{
		margin-top: 0px;
	}

	.rtl .counter-one-image{
		margin-right: 0px;
	}

	.rtl .counter-one_image-layer{
		right: 50px;
	}

	.rtl .counter-one_connt-outer{
		margin-left: 0px;
	}

	.rtl .header-style-two .header-upper .logo{
		margin: 0 auto;
	}

	.rtl .faq-one_accordian-outer{
		margin-right: 0px;
	}

	.rtl .main-header.header-style-three .header-lower .d-flex{
		justify-content: space-between !important;
	}

	.rtl .slider-three_content-inner{
		padding-bottom: 0px;
	}

	.rtl .about-three_map{
		margin-left: 0px;
	}

	.rtl .services-five_blocks-outer .services-five_carousel{
		margin-left: 0px;
	}

	.rtl .gallery-four_image{
		left: 0px;
		right: 0px;
	}

	.rtl .slider-four_heading{
		margin-left: 0px;
	}

	.rtl .shop-detail_content-column .inner-column{
		padding-right: 0px;
	}

}

@media only screen and (max-width: 820px){

}

@media only screen and (max-width: 767px){

	.rtl .service-block_one-inner{
		text-align: center !important;
	}

	.rtl .watch-one_form-outer{
		padding: 40px 20px 0px;
	}

	.rtl .counter-one_image-layer{
		right: 0px;
	}

	.rtl .counter-one_play{
		margin: 0 auto;
		margin-bottom: 30px;
	}

	.rtl .app-buttons{
		margin-left: 0px;
	}

	.rtl .internet-one_image{
		margin-right: 0px;
	}

	.rtl .review-author_box{
		padding-right: 0px;
	}

	.rtl .review-author_box .rating{
		right: 0px;
		left: auto;
	}

}

@media only screen and (max-width: 599px){

	.clients-three .inner-container{
		padding: 30px 30px;
	}

}

@media only screen and (max-width: 479px) {

	.rtl .about-block_one-content{
		margin-right: 0px;
	}

	.rtl .service-three_btn{
		padding: 20px 20px;
	}

	.rtl .service-three_btn .icon{
		right: 0px;
	}

	.rtl .testimonial-block_two-content{
		padding-right: 15px;
	}

	.rtl .header-style-three.fixed-header .header-lower .logo,
	.rtl .header-style-three .header-lower .logo{
		margin-left: 0px;
	}

	.rtl .feature-block_one-inner{
		padding-right: 0px;
	}

}