@charset "utf-8";

/* CSS Document */

:root {
	
	/* #df0303 in decimal RGB */
    --main-color: rgb(234,27,41);
	--main-color-rgb:234,27,41;
	
	/* #2a2373 in decimal RGB */
	--color-two: rgb(42,35,115);
	--color-two-rgb:42,35,115;
	
}