import{ao as o,j as t}from"./main-78369d74.js";const n=o(t.jsx("path",{d:"M10 6 8.59 7.41 13.17 12l-4.58 4.59L10 18l6-6-6-6z"}),"ChevronRightOutlined");export{n as C};
//# sourceMappingURL=ChevronRight-4d13b02f.js.map
