
/*** 

====================================================================
	Main Footer
====================================================================

***/

.main-footer{
	position:relative;
}

.main-footer_image{
	position: absolute;
	left: 0px;
	top: 0px;
	right: 0px;
	bottom: 0px;
	background-size: cover;
}

.main-footer_image::before{
	position: absolute;
	content: '';
	left: 0px;
	top: 0px;
	right: 0px;
	bottom: 0px;
	opacity: 0.94;
	background: var(--main-color);
	background: radial-gradient(circle farthest-corner at center center, rgba(var(--main-color-rgb), 0.90) 0%, var(--color-two) 55%);
}

.main-footer .widgets-section{
	position:relative;
	padding: 100px 0px 30px;
}

.main-footer .widgets-section .row{
	margin: 0px -40px;
}

.main-footer .footer_column{
	position: relative;
	padding: 0px 40px;
	margin-bottom: 30px;
}

.footer-title{
	font-weight: 400;
	margin-bottom: 30px;
	color: var(--white-color);
	text-transform: capitalize;
}

.footer-text{
	position: relative;
	font-size: 16px;
	line-height: 26px;
	max-width: 380px;
	margin-bottom: 25px;
	color: var(--color-four);
	font-family: 'DM Sans', sans-serif;
}

.footer-logo{
	position: relative;
	padding: 10px 25px;
	margin-bottom: 30px;
	border-radius: 10px;
	display: inline-block;
	background-color: var(--white-color);
}

.app-buttons{
	position: relative;
	gap: 15px;
	margin-right: -45px;
}

.app-buttons .app-btn{
	position: relative;
	font-size: 14px;
	border-radius: 8px;
	color: var(--white-color);
	padding: 12px 24px 12px 55px;
	font-family: 'DM Sans', sans-serif;
	transition:all 500ms ease;
	-moz-transition:all 500ms ease;
	-webkit-transition:all 500ms ease;
	-ms-transition:all 500ms ease;
	-o-transition:all 500ms ease;
	background-color: rgba(var(--white-color-rgb), 0.15);
}

.app-buttons .app-btn span{
	position: absolute;
	left: 15px;
	top: 22px;
	font-size: 28px;
	line-height: 1em;
	color: var(--main-color);
}

.app-buttons .app-btn i{
	position: relative;
	display: block;
	font-weight: 500;
	margin-top: 5px;
	transition:all 500ms ease;
	-moz-transition:all 500ms ease;
	-webkit-transition:all 500ms ease;
	-ms-transition:all 500ms ease;
	-o-transition:all 500ms ease;
	font-family: 'Unbounded', sans-serif;
}

.app-buttons .app-btn:hover{
	color: var(--color-three);
	background-color: var(--white-color);
}

.app-buttons .app-btn:hover i{
	color: var(--color-two);
}

.links-widget{
	position: relative;
	border-radius: 10px;
	padding: 25px 30px;
	max-width: 310px;
	margin-left: 30px;
	background-color: rgba(var(--white-color-rgb), 0.15);
}

/* Footer List */

.footer-list{
	position: relative;
}

.footer-list li{
	position: relative;
	margin-bottom: 18px;
}

.footer-list li a{
	position: relative;
	font-size: 18px;
	font-weight: 400;
	color: var(--white-color);
	text-transform: capitalize;
	font-family: 'DM Sans', sans-serif;
}

.footer-list li a:hover{
	position: relative;
	color: var(--main-color);
}

.footer-list li span{
	position: relative;
	font-size: 14px;
	padding: 3px 12px;
	margin-left: 5px;
	border-radius: 50px;
	display: inline-block;
	color: var(--white-color);
	background-color: var(--main-color);
}

/* Gallery Widget */

.gallery-widget .carousel-outer{
	position: relative;
	padding-right: 50px;
	margin-bottom: 25px;
}

.gallery-widget .instagram-image{
	position: relative;
	border-radius: 8px;
	overflow: hidden;
}

.gallery-widget .instagram-image img{
	position: relative;
	width: 100%;
	display: block;
}

.gallery-widget .instagram-carousel-next{
	position: absolute;
	right: 0px;
	top: 50%;
	font-size: 22px;
	line-height: 1em;
	margin-top: -15px;
	color: var(--white-color);
}

.gallery-widget .instagram-carousel-next:hover{
	color: var(--main-color);
}

.timing-list{
	position: relative;
}

.timing-list li{
	position: relative;
	font-size: 18px;
	margin-bottom: 20px;
	color: var(--white-color);
	font-family: 'DM Sans', sans-serif;
}

.timing-list li span{
	position: absolute;
	right: 0px;
}

/* Footer Bottom */

.footer-bottom{
	position: relative;
	padding: 25px 0px;
}

.footer-bottom::before{
	position:absolute;
	content:'';
	right:0px;
	top:0px;
	left: 0px;
	height:2px;
	background: rgba(255,255,255,0);
	background: linear-gradient(to right, rgba(255,255,255,0) 0%, var(--main-color) 50%, rgba(255,255,255,0) 100%);
}

.main-footer_copyright{
	position: relative;
	font-size: 16px;
	color: var(--white-color);
}

.main-footer_copyright a{
	position: relative;
	color: var(--white-color);
}

/* Footer Social Box */

.footer-social_box{
	position: relative;
}

.footer-social_box a{
	position: relative;
	width: 36px;
	height: 36px;
	line-height: 34px;
	font-size: 14px;
	margin-left: 5px;
	text-align: center;
	border-radius: 50px;
	display: inline-block;
	color: var(--white-color);
	border: 1px solid rgba(255,255,255,0.15);
}

.footer-social_box a:hover{
	color: var(--white-color);
	border-color: var(--main-color);
	background-color: var(--main-color);
}

.footer-bottom_nav{
	position: relative;
}

.footer-bottom_nav li{
	position: relative;
	margin-right: 15px;
	display: inline-block;
}

.footer-bottom_nav li a{
	position: relative;
	font-size: 16px;
	color: var(--white-color);
}

.footer-bottom_nav li:last-child{
	margin-right: 0px;
}

.footer-bottom_nav li a:hover{
	color: var(--main-color);
}

/*** 

====================================================================
	Footer Style Two
====================================================================

***/

.footer-style_two{
	position:relative;
	padding-top: 100px;
}

.footer-style_two-image{
	position: absolute;
	left: 0px;
	top: 0px;
	right: 0px;
	bottom: 0px;
	background-size: cover;
}

.footer-style_two-image.alternate::before{
	background: var(--main-color);
    background: radial-gradient(circle farthest-corner at center center, rgba(var(--main-color-rgb), 0.90) 0%, var(--color-two) 55%);
}

.footer-style_two-image::before{
	position: absolute;
	content: '';
	left: 0px;
	top: 0px;
	right: 0px;
	bottom: 0px;
	opacity: 0.95;
	background-color: var(--color-two);
}

.footer-style_two .widgets-section{
	position:relative;
	padding: 100px 0px 50px;
}

.footer-style_two .widgets-section .row{
	margin: 0px -40px;
}

.footer-style_two .footer_column{
	position: relative;
	padding: 0px 40px;
	margin-bottom: 30px;
}

.footer-style_two .logo{
	position: relative;
	padding-bottom: 45px;
	margin-right: 120px;
	margin-top: 30px;
	border-bottom: 2px solid rgba(var(--white-color-rgb), 0.25);
}

/* Footer Social Box */

.footer-two_socials{
	position: relative;
	padding-top: 40px;
}

.footer-two_socials a{
	position: relative;
	width: 56px;
	height: 56px;
	font-size: 20px;
	margin-right: 10px;
	line-height: 54px;
	text-align: center;
	border-radius: 50px;
	display: inline-block;
	color: var(--white-color);
	border: 1px solid rgba(255,255,255,0.15);
}

.footer-two_socials a:hover{
	color: var(--white-color);
	border-color: var(--main-color);
	background-color: var(--main-color);
}

.footer-two_subscribe-column{
	position: relative;
}

.footer-two_subscribe-column .inner-column{
	position: relative;
	padding: 40px 40px;
	border-radius: 18px;
	background-color: rgba(var(--white-color-rgb), 0.10);
}

.footer-two_subscribe-column h4{
	font-weight: 500;
	color: var(--white-color);
}

.footer-two_subscribe-column .text{
	position: relative;
	font-size: 16px;
	margin-top: 15px;
	margin-bottom: 30px;
	color: var(--color-four);
	font-family: 'DM Sans', sans-serif;
}

/* Subscribe Box */

.subscribe-box{
	position:relative;
	margin-top: var(--margin-top-5);
}

.subscribe-box .form-group{
	position:relative;
	margin:0px;
	width:100%;
	max-width:100%;
	overflow:hidden;
	border: 1px solid rgba(var(--black-color-rgb), 0.10);
}

.subscribe-box .form-group input[type="text"],
.subscribe-box .form-group input[type="email"]{
	position:relative;
	line-height:43px;
	background:none;
	display:block;
	height:80px;
	width:100%;
	font-size:16px;
	box-shadow:inherit;
	border-radius: 50px;
	color:var(--color-three);
	padding:10px 55px 10px 35px;
	transition:all 500ms ease;
	-moz-transition:all 500ms ease;
	-webkit-transition:all 500ms ease;
	-ms-transition:all 500ms ease;
	-o-transition:all 500ms ease;
	background-color: var(--white-color);
}

.subscribe-box .form-group input::placeholder,
.subscribe-box .form-group textarea::placeholder{
	color:var(--color-three);
}

.subscribe-box .form-group button{
	position:absolute;
	right:5px;
	top:5px;
	cursor:pointer;
	font-size:14px;
	padding:23px 48px;
}

/* Footer List */

.footer-list_two{
	position: relative;
}

.footer-list_two li{
	position: relative;
	margin-right: 30px;
	margin-bottom: 20px;
	display: inline-block;
}

.footer-list_two li a{
	position: relative;
	font-size: 18px;
	font-weight: 400;
	color: var(--white-color);
	text-transform: capitalize;
	font-family: 'DM Sans', sans-serif;
}

.footer-list_two li a:hover{
	position: relative;
	color: var(--main-color);
}


.instagram-widget .images-outer{
	position:relative;
	margin:0px -3px;
}

.instagram-widget .image-box{
	position:relative;
	float:left;
	width:33.333%;
	padding:0px 6px;
	margin-bottom:10px;
}

.instagram-widget .image-box img{
	position:relative;
	display:block;
	width:100%;
	overflow: hidden;
	border-radius: 8px;
	-webkit-transition:all 300ms ease;
	-ms-transition:all 300ms ease;
	-o-transition:all 300ms ease;
	-moz-transition:all 300ms ease;
	transition:all 300ms ease;
}

.instagram-widget .image-box img:hover{
	opacity:0.70;
}

.footer-style_two .footer-bottom{
	z-index: 1;
}

.footer-style_two .footer-bottom::before{
	display: none;
}

.footer-style_two .footer-bottom:after{
	position: absolute;
	content: '';
	left: 0px;
	top: 0px;
	right: 0px;
	bottom: 0px;
	z-index: -1;
	opacity: 0.30;
	background: rgba(255,255,255,0);
	background: linear-gradient(to right, rgba(255,255,255,0) 0%, var(--main-color) 50%, rgba(255,255,255,0) 100%);
}