/* Banqix TV & Internet Business HTML-5 Template */
/* Dark Version Style CSS Code */

.dark-body,
.dark-body .news-two_circle-layer,
.dark-body .testimonial-three .inner-container::before,
.dark-body .products-block_one-inner{
	background-color: #22253c;
}

.dark-body .news-four,
.dark-body .news-two,
.dark-body .contact-one .inner-container,
.dark-body .services-three,
.dark-body .services-one.style-two,
.dark-body .connection-one_color,
.dark-body .about-four_pattern-layer,
.dark-body .internet-one_content,
.dark-body .watch-one .inner-container,
.dark-body .products-one,
.dark-body .post-share-options .social-links a,
.dark-body .post-share-options .post-tags a,
.dark-body .service-detail_list-two li i,
.dark-body .testimonial-two.style-two,
.dark-body .subscribe-one{
	background-color: #2d3049;
}

.dark-body .about-three_block-heading,
.dark-body .about-three_text,
.dark-body .about-two_list li,
.dark-body .news-block_one-heading a,
.dark-body .news-block_one-meta li,
.dark-body .products-block_one-title a,
.dark-body .subscribe-one_mb span,
.dark-body .subscribe-one_mb sup,
.dark-body .internet-one_clock,
.dark-body .service-block_one-text,
.dark-body .service-block_three-list li,
.dark-body .service-block_three-heading a,
.dark-body .internet-one_content .title,
.dark-body .internet-one_list li,
.dark-body .about-four_list li,
.dark-body .privacy-section h3,
.dark-body .privacy-section p,
.dark-body .privacy-section h4,
.dark-body .team-detail p,
.dark-body .sidebar-title,
.dark-body .contact-one_list li,
.dark-body .contact-one_title,
.dark-body .contact-one_list li h4,
.dark-body .blog-detail_heading,
.dark-body .news-block_two-more,
.dark-body .shop-detail_socials .share,
.dark-body .quantity-box strong,
.dark-body .shop-detail_list li,
.dark-body .shop-detail_text,
.dark-body .shop-detail_title,
.dark-body .service-detail p,
.dark-body .service-detail_list li,
.dark-body .service-detail_heading,
.dark-body .service-detail_subheading,
.dark-body .team-detail_list li,
.dark-body .blog-detail p,
.dark-body .error-section h1,
.dark-body .blog-detail_list li,
.dark-body .post-share-options .post-tags a,
.dark-body .blog-detail blockquote,
.dark-body .service-detail_list-two li,
.dark-body .service-detail_tab .text,
.dark-body .team-detail_info-list li span,
.dark-body .default-skill-title,
.dark-body .review-author_box h5,
.dark-body .review-author_box-text,
.dark-body .shop-detail_check-list li,
.dark-body .shop-detail .lower-box p,
.dark-body .shop-detail .lower-box h3,
.dark-body .team-detail-subheading,
.dark-body .review-author_box-date,
.dark-body .privacy-section .privacy-list li,
.dark-body .counter-block_three-designation,
.dark-body .blog-detail .blog-detail_subheading,
.dark-body .post-share-options .social-links a,
.dark-body .internet-one_content .lower-box h6,
.dark-body .accordion-box .block .icon-outer .icon,
.dark-body .accordion-box .block .acc-btn,
.dark-body .service-block_one-heading a,
.dark-body .sec-title_heading{
	color: var(--white-color);
}

.dark-body .testimonial-two_bg-color,
.dark-body .watch-one_image,
.dark-body .testimonial-one_image{
	opacity: 0.10;
}

.dark-body .testimonial-one_carousel-pagination .swiper-pagination-bullet{
	border-color: rgba(255,255,255,0.80);
}

.dark-body .counter-two_icon{
	filter: invert(100%);
}

.dark-body .internet-one_content .lower-box::before{
	opacity: 0.20;
	background-color: var(--white-color);
}

.dark-body .testimonial-carousel_two-pagination .swiper-pagination-bullet{
	background-color: var(--white-color);
}

.dark-body .contact-one_list li,
.dark-body .review-author_box,
.dark-body .post-share-options .post-tags a,
.dark-body .shop-detail_gallery-column .thumb,
.dark-body .sidebar-widget .widget-content,
.dark-body .privacy-section .privacy-content,
.dark-body .internet-one_content .lower-box,
.dark-body .service-block_three-content::before,
.dark-body .accordion-box .block{
	border-color: rgba(var(--white-color-rgb), 0.20);
}

.dark-body .service-block_one-inner:before{
	background:#ffffff;
	background:-webkit-linear-gradient(top,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
	background:-moz-linear-gradient(top,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
	background:-ms-linear-gradient(top,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
	background:-o-linear-gradient(top,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
}

.dark-body .service-block_one-inner:after{
	background:#ffffff;
	background:-webkit-linear-gradient(right,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
	background:-moz-linear-gradient(right,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
	background:-ms-linear-gradient(right,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
	background:-o-linear-gradient(right,rgba(0,0,0,0),#ffffff,rgba(0,0,0,0));
}