import{ao as r,j as s,z as n,I as t,c as g,D as c,k as x,l}from"./main-78369d74.js";const d=r(s.jsx("path",{d:"M9 8a1 1 0 0 0-1-1H5.5a1 1 0 1 0 0 2H7v4a1 1 0 0 0 2 0zM4 0h8a4 4 0 0 1 4 4v8a4 4 0 0 1-4 4H4a4 4 0 0 1-4-4V4a4 4 0 0 1 4-4zm4 5.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"}),"InfoDialogTrigger");function m({title:a,body:e,dialogSize:i="sm",className:o}){return s.jsxs(n,{type:"popover",triggerOnHover:!0,children:[s.jsx(t,{className:g("ml-4 text-muted opacity-70",o),iconSize:"xs",size:"2xs",children:s.jsx(d,{viewBox:"0 0 16 16"})}),s.jsxs(c,{size:i,children:[a&&s.jsx(x,{padding:"px-18 pt-12",size:"md",hideDismissButton:!0,children:a}),s.jsx(l,{children:e})]})]})}export{m as I};
//# sourceMappingURL=info-dialog-trigger-7dec76dd.js.map
