import{H as a,j as e,t as s,x as g,c as r,p as t,s as i,b as h,r as p,a as n,d as u,e as c}from"./c-2796b676.js";import"./main-78369d74.js";a.registerLanguage("javascript",e);a.registerLanguage("typescript",s);a.registerLanguage("html",g);a.registerLanguage("css",r);a.registerLanguage("php",t);a.registerLanguage("shell",i);a.registerLanguage("bash",h);a.registerLanguage("ruby",p);a.registerLanguage("python",n);a.registerLanguage("java",u);a.registerLanguage("c",c);export{a as hljs};
//# sourceMappingURL=highlight-2d51142f.js.map
