import{j as s,c as d,I as l,G as x,ao as p}from"./main-78369d74.js";function g({title:i,description:n,actions:r,color:e="primary",className:c,size:m="md",leadingIcon:t,onClose:a}){return s.jsxs("div",{className:d(c,"rounded-panel px-10 pb-10",t||a?"py-4":"py-10",m==="sm"?"text-xs":"text-sm",e==="positive"&&"bg-positive/focus",e==="warning"&&"bg-warning/focus",e==="danger"&&"bg-danger/focus",e==="primary"&&"bg-primary/focus",e==="neutral"&&"border bg",e==="bgAlt"&&"border bg-alt"),children:[i&&s.jsxs("div",{className:"mb-4 flex items-center gap-6",children:[t,s.jsx("div",{className:"font-medium",children:i}),a?s.jsx(l,{size:"xs",className:"ml-auto",onClick:()=>a(),children:s.jsx(x,{})}):null]}),n&&s.jsx("div",{children:n}),r&&s.jsx("div",{className:"mt-14",children:r})]})}const b=p(s.jsx("path",{d:"m14.06 9.02.92.92L5.92 19H5v-.92l9.06-9.06M17.66 3c-.25 0-.51.1-.7.29l-1.83 1.83 3.75 3.75 1.83-1.83c.39-.39.39-1.02 0-1.41l-2.34-2.34c-.2-.2-.45-.29-.71-.29zm-3.6 3.19L3 17.25V21h3.75L17.81 9.94l-3.75-3.75z"}),"EditOutlined");export{b as E,g as S};
//# sourceMappingURL=Edit-d653f744.js.map
