body {
  overflow-x: hidden;
  direction: rtl;
}

.owl-carousel {
  direction: ltr;
}

.owl-carousel .owl-nav,
.owl-carousel .owl-dots,
.owl-carousel .owl-item {
  direction: rtl;
}

.contact__input-box .bootstrap-select .dropdown-menu,
.bootstrap-select .dropdown-toggle .filter-option {
  text-align: right;
}

.list-unstyled {
  padding-right: 0;
}

.testimonials-card__author {
  clip-path: polygon(0 0, 100% 0%, 100% 100%, 12% 100%);
}

.main-slider-one__carousel .owl-dots {
  width: 98%;
}
/*# sourceMappingURL=ienet-custom-rtl.css.map */
