.recent-area{
    .single-recent-cap{
        .recent-img{
            overflow: hidden;
            & img{
                width: 100%;
                transform: scale(1);
                @include transition(.5s);
            }
        }
        .recent-cap{
            padding: 20px 30px 20px 30px;
            background: #fcfdff;
            & span{
                color: $theme_color;
                font-size: 14px;
                margin-bottom: 20px;
                display: block;
            }
            & h4{
                & a{
                color: $heading-color;
                font-size: 20px;
                margin-bottom: 20px;
                font-weight: 500px;
                &:hover{
                    color: $theme_color;
                }
                }

            }
            p{
                color: #aebccb;
                font-size: 14px;
            }
        }
    }
}

.single-recent-cap:hover .recent-img img{
    transform: scale(1.1);
}